@@ -37,7 +37,7 @@ class SpinButton(Control):
     @value.setter
     def value(self, value):
         assert value == None or isinstance(value, float) or isinstance(value, int), "value must be a float"
-        self._set_attr("value", float(value))
+        self._set_attr("value", value)
 
 # label
     @property
@@ -56,7 +56,7 @@ class SpinButton(Control):
     @min.setter
     def min(self, value):
         assert value == None or isinstance(value, float) or isinstance(value, int), "min must be a float"
-        self._set_attr("min", float(value))
+        self._set_attr("min", value)
 
 # max
     @property
@@ -66,7 +66,7 @@ class SpinButton(Control):
     @max.setter
     def max(self, value):
         assert value == None or isinstance(value, float) or isinstance(value, int), "max must be a float"
-        self._set_attr("max", float(value))
+        self._set_attr("max", value)
 
 # step
     @property
@@ -76,7 +76,7 @@ class SpinButton(Control):
     @step.setter
     def step(self, value):
         assert value == None or isinstance(value, float) or isinstance(value, int), "step must be a float"
-        self._set_attr("step", float(value))
+        self._set_attr("step", value)
 
 # icon
     @property
